# Cinetica

Cinetica es una librería de Python diseñada para proporcionar varios módulos para cálculos y simulaciones de física, incluyendo movimientos rectilíneos, parabólicos, circulares, oscilatorios, relativos y espaciales (3D).

## Instalación

```bash
pip install cinetica
```

Para documentación detallada y ejemplos de uso, por favor consulta [DOCS.md](DOCS.md).

## Contribuciones

¡Las contribuciones son bienvenidas! Por favor, consulta el archivo `CONTRIBUTING.md` para más detalles.

## Licencia

Este proyecto está bajo la Licencia MIT - consulta el archivo [LICENSE](LICENSE) para más detalles.
